function y = computehenon(N, a, b, y0)
%
% arguments:
%  N: number of values of Henon map to calculate
%  a: (1.4)
%  b: (0.3)
%  y0: initial conditions [0,0]
%
% return:
%  y: Henon map values
%

% set initial conditions
%
y = y0;

for i=3:N
    y=[y,a-y(i-1)^2+b*y(i-2)];
end
    